import React from "react";
import {classes, Modify} from "../../Utils";
import {SubmenuFloat} from "./SubmenuFloat";

export type SubmenuItemProperties = React.PropsWithChildren<Modify<React.AnchorHTMLAttributes<HTMLAnchorElement>, {
}>>;

/**
 * Main component of a submenu item.
 */
export const SubmenuItem = React.forwardRef<HTMLAnchorElement, SubmenuItemProperties>(function SubmenuItem({className, children, ...props}: SubmenuItemProperties, ref)
{
	return (
		<a ref={ref} className={classes("item", className)} {...props}>{children}</a>
	);
});

/**
 * A submenu item that open a submenu.
 */
export function SubmenuItemSubmenu({submenu, className, children, ...props}: Modify<SubmenuItemProperties, {
	/**
	 * The submenu content.
	 */
	submenu: React.ReactNode;
}>)
{
	return (
		<SubmenuFloat submenu={submenu} role={"menu"} floatingOptions={{ placement: "right-start" }}>
			<SubmenuItem className={classes("submenu", className)} {...props}>{children}</SubmenuItem>
		</SubmenuFloat>
	);
}
